@@ -17,16 +17,16 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-'''
+"""
 Created on Sep 18, 2009
 
 @author: sgallagh
-'''
+"""
 import unittest
 import os
 import shutil
 import tempfile
-from stat import *
+from stat import ST_MODE, S_IMODE
 
 import sys
 
@@ -44,8 +44,8 @@ def create_temp_dir():
     return tempfile.mkdtemp(dir=test_dir)
 
 
-def striplist(l):
-    return([x.strip() for x in l])
+def striplist(the_list):
+    return ([x.strip() for x in the_list])
 
 
 class SSSDConfigTestValid(unittest.TestCase):
@@ -57,7 +57,7 @@ class SSSDConfigTestValid(unittest.TestCase):
 
     def testServices(self):
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
-                                srcdir + "/etc/sssd.api.d")
+                                           srcdir + "/etc/sssd.api.d")
         sssdconfig.import_config(srcdir + "/testconfigs/sssd-valid.conf")
 
         # Validate services
@@ -66,11 +66,10 @@ class SSSDConfigTestValid(unittest.TestCase):
         self.assertTrue('nss' in services)
         self.assertTrue('pam' in services)
 
-        #Verify service attributes
+        # Verify service attributes
         sssd_service = sssdconfig.get_service('sssd')
         service_opts = sssd_service.list_options()
 
-
         self.assertTrue('services' in service_opts.keys())
         service_list = sssd_service.get_option('services')
         self.assertTrue('nss' in service_list)
@@ -82,11 +81,11 @@ class SSSDConfigTestValid(unittest.TestCase):
 
         del sssdconfig
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
-                                     srcdir + "/etc/sssd.api.d")
+                                           srcdir + "/etc/sssd.api.d")
         sssdconfig.new_config()
         sssdconfig.delete_service('sssd')
-        new_sssd_service = sssdconfig.new_service('sssd');
-        new_options = new_sssd_service.list_options();
+        new_sssd_service = sssdconfig.new_service('sssd')
+        new_options = new_sssd_service.list_options()
 
         self.assertTrue('debug_level' in new_options)
         self.assertEqual(new_options['debug_level'][0], int)
@@ -121,16 +120,16 @@ class SSSDConfigTestValid(unittest.TestCase):
 
     def testDomains(self):
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
-                                srcdir + "/etc/sssd.api.d")
+                                           srcdir + "/etc/sssd.api.d")
         sssdconfig.import_config(srcdir + "/testconfigs/sssd-valid.conf")
 
-        #Validate domain list
+        # Validate domain list
         domains = sssdconfig.list_domains()
         self.assertTrue('LDAP' in domains)
         self.assertTrue('PROXY' in domains)
         self.assertTrue('IPA' in domains)
 
-        #Verify domain attributes
+        # Verify domain attributes
         ipa_domain = sssdconfig.get_domain('IPA')
         domain_opts = ipa_domain.list_options()
         self.assertTrue('debug_level' in domain_opts.keys())
@@ -152,7 +151,7 @@ class SSSDConfigTestValid(unittest.TestCase):
 
     def testListProviders(self):
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
-                                srcdir + "/etc/sssd.api.d")
+                                           srcdir + "/etc/sssd.api.d")
 
         sssdconfig.new_config()
         junk_domain = sssdconfig.new_domain('junk')
@@ -161,7 +160,7 @@ class SSSDConfigTestValid(unittest.TestCase):
 
     def testCreateNewLDAPConfig(self):
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
-                                srcdir + "/etc/sssd.api.d")
+                                           srcdir + "/etc/sssd.api.d")
 
         sssdconfig.new_config()
 
@@ -173,20 +172,20 @@ class SSSDConfigTestValid(unittest.TestCase):
 
         of = self.tmp_dir + '/testCreateNewLDAPConfig.conf'
 
-        #Ensure the output file doesn't exist
+        # Ensure the output file doesn't exist
         try:
             os.unlink(of)
-        except:
+        except OSError:
             pass
 
-        #Write out the file
+        # Write out the file
         sssdconfig.write(of)
 
-        #Verify that the output file has the correct permissions
+        # Verify that the output file has the correct permissions
         mode = os.stat(of)[ST_MODE]
 
-        #Output files should not be readable or writable by
-        #non-owners, and should not be executable by anyone
+        # Output files should not be readable or writable by
+        # non-owners, and should not be executable by anyone
         self.assertFalse(S_IMODE(mode) & 0o177)
 
         # try to import saved configuration file
@@ -194,13 +193,12 @@ class SSSDConfigTestValid(unittest.TestCase):
                                        srcdir + "/etc/sssd.api.d")
         config.import_config(configfile=of)
 
-        #Remove the output file
+        # Remove the output file
         os.unlink(of)
 
-
     def testModifyExistingConfig(self):
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
-                                srcdir + "/etc/sssd.api.d")
+                                           srcdir + "/etc/sssd.api.d")
         sssdconfig.import_config(srcdir + "/testconfigs/sssd-valid.conf")
 
         ldap_domain = sssdconfig.get_domain('LDAP')
@@ -225,20 +223,20 @@ class SSSDConfigTestValid(unittest.TestCase):
 
         of = self.tmp_dir + '/testModifyExistingConfig.conf'
 
-        #Ensure the output file doesn't exist
+        # Ensure the output file doesn't exist
         try:
             os.unlink(of)
-        except:
+        except OSError:
             pass
 
-        #Write out the file
+        # Write out the file
         sssdconfig.write(of)
 
-        #Verify that the output file has the correct permissions
+        # Verify that the output file has the correct permissions
         mode = os.stat(of)[ST_MODE]
 
-        #Output files should not be readable or writable by
-        #non-owners, and should not be executable by anyone
+        # Output files should not be readable or writable by
+        # non-owners, and should not be executable by anyone
         self.assertFalse(S_IMODE(mode) & 0o177)
 
         # try to import saved configuration file
@@ -250,27 +248,27 @@ class SSSDConfigTestValid(unittest.TestCase):
 
         # check internal state before parsing strings which is done in
         # get_domain or get_service
-        debug_option = [ x for x in config.options('domain/LDAP')
-                           if x['name'] == 'debug_level']
+        debug_option = [x for x in config.options('domain/LDAP')
+                        if x['name'] == 'debug_level']
         self.assertEqual(len(debug_option), 1)
         self.assertEqual(debug_option[0]['value'], '3')
 
-        debug_option = [ x for x in config.options('domain/PROXY')
-                           if x['name'] == 'debug_level']
+        debug_option = [x for x in config.options('domain/PROXY')
+                        if x['name'] == 'debug_level']
         self.assertEqual(len(debug_option), 1)
         self.assertEqual(debug_option[0]['value'], '0x1f10')
 
-        debug_option = [ x for x in config.options('sudo')
-                           if x['name'] == 'debug_level']
+        debug_option = [x for x in config.options('sudo')
+                        if x['name'] == 'debug_level']
         self.assertEqual(len(debug_option), 1)
         self.assertEqual(debug_option[0]['value'], '0x2210')
 
-        debug_option = [ x for x in config.options('pam')
-                           if x['name'] == 'debug_level']
+        debug_option = [x for x in config.options('pam')
+                        if x['name'] == 'debug_level']
         self.assertEqual(len(debug_option), 1)
         self.assertEqual(debug_option[0]['value'], '9')
 
-        #Remove the output file
+        # Remove the output file
         os.unlink(of)
 
     def testSpaces(self):
@@ -281,6 +279,7 @@ class SSSDConfigTestValid(unittest.TestCase):
         self.assertEqual(ldap_domain.get_option('auth_provider'), 'ldap')
         self.assertEqual(ldap_domain.get_option('id_provider'), 'ldap')
 
+
 class SSSDConfigTestInvalid(unittest.TestCase):
     def setUp(self):
         pass
@@ -293,7 +292,8 @@ class SSSDConfigTestInvalid(unittest.TestCase):
                                            srcdir + "/etc/sssd.api.d")
         sssdconfig.import_config(srcdir + "/testconfigs/sssd-invalid-badbool.conf")
         self.assertRaises(TypeError,
-                          sssdconfig.get_domain,'IPA')
+                          sssdconfig.get_domain, 'IPA')
+
 
 class SSSDConfigTestSSSDService(unittest.TestCase):
     def setUp(self):
@@ -305,7 +305,7 @@ class SSSDConfigTestSSSDService(unittest.TestCase):
 
     def testInit(self):
         # Positive test
-        service = SSSDConfig.SSSDService('sssd', self.schema)
+        SSSDConfig.SSSDService('sssd', self.schema)
 
         # Type Error test
         # Name is not a string
@@ -352,6 +352,7 @@ class SSSDConfigTestSSSDService(unittest.TestCase):
             'domain_resolution_order',
             'try_inotify',
             'monitor_resolv_conf',
+            'implicit_pac_responder',
         ]
 
         self.assertTrue(type(options) == dict,
@@ -373,28 +374,28 @@ class SSSDConfigTestSSSDService(unittest.TestCase):
                         "Option values should be a tuple")
 
         self.assertTrue(options['reconnection_retries'][0] == int,
-                        "reconnection_retries should require an int. " +
+                        "reconnection_retries should require an int. "
                         "list_options is requiring a %s" %
                         options['reconnection_retries'][0])
 
-        self.assertTrue(options['reconnection_retries'][1] == None,
-                        "reconnection_retries should not require a subtype. " +
+        self.assertTrue(options['reconnection_retries'][1] is None,
+                        "reconnection_retries should not require a subtype. "
                         "list_options is requiring a %s" %
                         options['reconnection_retries'][1])
 
-        self.assertTrue(options['reconnection_retries'][3] == None,
+        self.assertTrue(options['reconnection_retries'][3] is None,
                         "reconnection_retries should have no default")
 
         self.assertTrue(type(options['services']) == tuple,
                         "Option values should be a tuple")
 
         self.assertTrue(options['services'][0] == list,
-                        "services should require an list. " +
+                        "services should require an list. "
                         "list_options is requiring a %s" %
                         options['services'][0])
 
         self.assertTrue(options['services'][1] == str,
-                        "services should require a subtype of str. " +
+                        "services should require a subtype of str. "
                         "list_options is requiring a %s" %
                         options['services'][1])
 
@@ -425,12 +426,12 @@ class SSSDConfigTestSSSDService(unittest.TestCase):
                         "Option values should be a tuple")
 
         self.assertTrue(options['services'][0] == list,
-                        "services should require an list. " +
+                        "services should require an list. "
                         "list_options is requiring a %s" %
                         options['services'][0])
 
         self.assertTrue(options['services'][1] == str,
-                        "services should require a subtype of str. " +
+                        "services should require a subtype of str. "
                         "list_options is requiring a %s" %
                         options['services'][1])
 
@@ -467,7 +468,7 @@ class SSSDConfigTestSSSDService(unittest.TestCase):
     def testGetAllOptions(self):
         service = SSSDConfig.SSSDService('sssd', self.schema)
 
-        #Positive test
+        # Positive test
         options = service.get_all_options()
         control_list = ['services']
 
@@ -498,6 +499,7 @@ class SSSDConfigTestSSSDService(unittest.TestCase):
         self.assertRaises(SSSDConfig.NoOptionError, service.get_option, 'nosuchentry')
         service.remove_option('nosuchentry')
 
+
 class SSSDConfigTestSSSDDomain(unittest.TestCase):
     def setUp(self):
         self.schema = SSSDConfig.SSSDConfigSchema(srcdir + "/etc/sssd.api.conf",
@@ -508,7 +510,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
 
     def testInit(self):
         # Positive Test
-        domain = SSSDConfig.SSSDDomain('mydomain', self.schema)
+        SSSDConfig.SSSDDomain('mydomain', self.schema)
 
         # Negative Test - Name not a string
         self.assertRaises(TypeError, SSSDConfig.SSSDDomain, 2, self.schema)
@@ -523,7 +525,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
         self.assertEqual(domain.get_name(), 'mydomain')
 
     def testSetActive(self):
-        #Positive Test
+        # Positive Test
         domain = SSSDConfig.SSSDDomain('mydomain', self.schema)
 
         # Should default to inactive
@@ -634,12 +636,12 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
                         "Option values should be a tuple")
 
         self.assertTrue(options['max_id'][0] == int,
-                        "max_id should require an int. " +
+                        "max_id should require an int. "
                         "list_options is requiring a %s" %
                         options['max_id'][0])
 
-        self.assertTrue(options['max_id'][1] == None,
-                        "max_id should not require a subtype. " +
+        self.assertTrue(options['max_id'][1] is None,
+                        "max_id should not require a subtype. "
                         "list_options is requiring a %s" %
                         options['max_id'][1])
 
@@ -665,6 +667,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
              'krb5_renew_interval',
              'krb5_use_fast',
              'krb5_fast_principal',
+             'krb5_fast_use_anonymous_pkinit',
              'krb5_canonicalize',
              'krb5_use_enterprise_principal',
              'krb5_use_subdomain_realm',
@@ -828,6 +831,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
             'krb5_renew_interval',
             'krb5_use_fast',
             'krb5_fast_principal',
+            'krb5_fast_use_anonymous_pkinit',
             'krb5_canonicalize',
             'krb5_use_enterprise_principal',
             'krb5_use_subdomain_realm',
@@ -849,7 +853,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
                             'Option [%s] unexpectedly found' %
                             option)
 
-        #Test looking up all provider values
+        # Test looking up all provider values
         options = domain.list_provider_options('krb5')
         control_list.extend(['krb5_kpasswd'])
 
@@ -987,12 +991,12 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
                         "Option values should be a tuple")
 
         self.assertTrue(options['max_id'][0] == int,
-                        "config_file_version should require an int. " +
+                        "config_file_version should require an int. "
                         "list_options is requiring a %s" %
                         options['max_id'][0])
 
-        self.assertTrue(options['max_id'][1] == None,
-                        "config_file_version should not require a subtype. " +
+        self.assertTrue(options['max_id'][1] is None,
+                        "config_file_version should not require a subtype. "
                         "list_options is requiring a %s" %
                         options['max_id'][1])
 
@@ -1019,6 +1023,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
              'krb5_renew_interval',
              'krb5_use_fast',
              'krb5_fast_principal',
+             'krb5_fast_use_anonymous_pkinit',
              'krb5_canonicalize',
              'krb5_use_enterprise_principal',
              'krb5_use_subdomain_realm',
@@ -1153,7 +1158,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
         domain = SSSDConfig.SSSDDomain('sssd', self.schema)
 
         # Positive test - Change the name once
-        domain.set_name('sssd2');
+        domain.set_name('sssd2')
         self.assertEqual(domain.get_name(), 'sssd2')
         self.assertEqual(domain.oldname, 'sssd')
 
@@ -1166,6 +1171,7 @@ class SSSDConfigTestSSSDDomain(unittest.TestCase):
         self.assertRaises(TypeError,
                           domain.set_name, 4)
 
+
 class SSSDConfigTestSSSDConfig(unittest.TestCase):
     def setUp(self):
         self.tmp_dir = create_temp_dir()
@@ -1175,8 +1181,8 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
 
     def testInit(self):
         # Positive test
-        sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
-                                           srcdir + "/etc/sssd.api.d")
+        SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
+                              srcdir + "/etc/sssd.api.d")
 
         # Negative Test - No Such File
         self.assertRaises(IOError,
@@ -1203,7 +1209,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
             'domain/LDAP',
             'domain/INVALIDPROVIDER',
             'domain/INVALIDOPTION',
-            ]
+        ]
 
         for section in control_list:
             self.assertTrue(sssdconfig.has_section(section),
@@ -1231,7 +1237,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
                             "Option [%s] unexpectedly found" %
                             option)
 
-        #TODO: Check the types and values of the settings
+        # TODO: Check the types and values of the settings
 
         # Negative Test - Missing config file
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
@@ -1246,7 +1252,9 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         # Negative Test - Invalid config file version
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
                                            srcdir + "/etc/sssd.api.d")
-        self.assertRaises(SSSDConfig.ParsingError, sssdconfig.import_config, srcdir + "/testconfigs/sssd-badversion.conf")
+        self.assertRaises(SSSDConfig.ParsingError,
+                          sssdconfig.import_config,
+                          srcdir + "/testconfigs/sssd-badversion.conf")
 
         # Negative Test - Already initialized
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
@@ -1270,7 +1278,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         self.assertTrue('pam' in services)
         self.assertTrue('dp' in services)
 
-        #Verify service attributes
+        # Verify service attributes
         sssd_service = sssdconfig.get_service('sssd')
         service_opts = sssd_service.list_options()
 
@@ -1280,7 +1288,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         self.assertTrue('pam' in service_list)
         self.assertTrue('reconnection_retries' in service_opts)
 
-        #Validate domain list
+        # Validate domain list
         domains = sssdconfig.list_domains()
         self.assertTrue('LDAP' in domains)
         self.assertTrue('PROXY' in domains)
@@ -1380,7 +1388,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         self.assertRaises(SSSDConfig.AlreadyInitializedError, sssdconfig.new_config)
 
     def testWrite(self):
-        #TODO Write tests to compare output files
+        # TODO Write tests to compare output files
         pass
 
     def testListActiveServices(self):
@@ -1513,7 +1521,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         sssdconfig.new_config()
 
         # Positive Test
-        service = sssdconfig.delete_service('sssd')
+        sssdconfig.delete_service('sssd')
 
     def testSaveService(self):
         sssdconfig = SSSDConfig.SSSDConfig(srcdir + "/etc/sssd.api.conf",
@@ -1646,7 +1654,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
             'LDAP',
             'INVALIDPROVIDER',
             'INVALIDOPTION',
-            ]
+        ]
         inactive_domains = sssdconfig.list_inactive_domains()
 
         for domain in control_list:
@@ -1674,7 +1682,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
             'LDAP',
             'INVALIDPROVIDER',
             'INVALIDOPTION',
-            ]
+        ]
         domains = sssdconfig.list_domains()
 
         for domain in control_list:
@@ -1816,8 +1824,8 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
 
         # Positive test - Change the domain name and save it
         domain.set_name('example.com2')
-        self.assertEqual(domain.name,'example.com2')
-        self.assertEqual(domain.oldname,'example.com')
+        self.assertEqual(domain.name, 'example.com2')
+        self.assertEqual(domain.oldname, 'example.com')
         sssdconfig.save_domain(domain)
 
         self.assertTrue('example.com2' in sssdconfig.list_domains())
@@ -1843,9 +1851,9 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         self.assertTrue('example.com2' in sssdconfig.list_inactive_domains())
 
         self.assertEqual(len(sssdconfig.list_active_domains()),
-                         len(activelist)-1)
+                         len(activelist) - 1)
         self.assertEqual(len(sssdconfig.list_inactive_domains()),
-                         len(inactivelist)+1)
+                         len(inactivelist) + 1)
 
         # Positive test - Set the domain active and save it
         activelist = sssdconfig.list_active_domains()
@@ -1857,9 +1865,9 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         self.assertFalse('example.com2' in sssdconfig.list_inactive_domains())
 
         self.assertEqual(len(sssdconfig.list_active_domains()),
-                         len(activelist)+1)
+                         len(activelist) + 1)
         self.assertEqual(len(sssdconfig.list_inactive_domains()),
-                         len(inactivelist)-1)
+                         len(inactivelist) - 1)
 
         # Positive test - Set the domain inactive and save it
         activelist = sssdconfig.list_active_domains()
@@ -1871,9 +1879,9 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         self.assertTrue('example.com2' in sssdconfig.list_inactive_domains())
 
         self.assertEqual(len(sssdconfig.list_active_domains()),
-                         len(activelist)-1)
+                         len(activelist) - 1)
         self.assertEqual(len(sssdconfig.list_inactive_domains()),
-                         len(inactivelist)+1)
+                         len(inactivelist) + 1)
 
         # Positive test - Set the domain active and save it
         activelist = sssdconfig.list_active_domains()
@@ -1885,9 +1893,9 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
         self.assertFalse('example.com2' in sssdconfig.list_inactive_domains())
 
         self.assertEqual(len(sssdconfig.list_active_domains()),
-                         len(activelist)+1)
+                         len(activelist) + 1)
         self.assertEqual(len(sssdconfig.list_inactive_domains()),
-                         len(inactivelist)-1)
+                         len(inactivelist) - 1)
 
         # Positive test - Ensure that saved domains retain values
         domain.set_option('ldap_krb5_init_creds', True)
@@ -1903,26 +1911,25 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
 
         of = self.tmp_dir + '/testSaveDomain.out'
 
-        #Ensure the output file doesn't exist
+        # Ensure the output file doesn't exist
         try:
             os.unlink(of)
-        except:
+        except OSError:
             pass
 
-        #Write out the file
+        # Write out the file
         sssdconfig.write(of)
 
-        #Verify that the output file has the correct permissions
+        # Verify that the output file has the correct permissions
         mode = os.stat(of)[ST_MODE]
 
-        #Output files should not be readable or writable by
-        #non-owners, and should not be executable by anyone
+        # Output files should not be readable or writable by
+        # non-owners, and should not be executable by anyone
         self.assertFalse(S_IMODE(mode) & 0o177)
 
-        #Remove the output file
+        # Remove the output file
         os.unlink(of)
 
-
         domain2 = sssdconfig.get_domain('example.com2')
         self.assertTrue(domain2.get_option('ldap_krb5_init_creds'))
         self.assertFalse(domain2.get_option('ldap_id_use_start_tls'))
@@ -2045,7 +2052,7 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
             'domain/disabled_1',
             'domain/disabled_2',
             'domain/disabled_3',
-            ]
+        ]
 
         for section in control_list:
             self.assertTrue(sssdconfig.has_section(section),
@@ -2109,7 +2116,6 @@ class SSSDConfigTestSSSDConfig(unittest.TestCase):
                             "Domain [domain/%s] should be disabled" % domain)
 
 
-
 if __name__ == "__main__":
     error = 0
 
