@@ -49,18 +49,11 @@ extern hash_table_t *dp_requests;
  * So we set umask to 0111. */
 #define SCKT_RSP_UMASK 0111
 
-/* Neither the local provider nor the files provider have a back
- * end in the traditional sense and can always just consult
- * the responder's cache
+/* Files provider doesn't have a back end in the traditional sense
+ * and can always just consult the responder's cache
  */
 #define NEED_CHECK_PROVIDER(provider) \
-    (provider != NULL && \
-     ((!local_provider_is_built() || strcmp(provider, "local") != 0) && \
-      strcmp(provider, "files") != 0))
-
-#define NEED_CHECK_AUTH_PROVIDER(provider) \
-    (provider != NULL && \
-      (!local_provider_is_built() || strcmp(provider, "local") != 0))
+    ((provider != NULL) && (strcmp(provider, "files") != 0))
 
 /* needed until nsssrv.h is updated */
 struct cli_request {
@@ -148,6 +141,7 @@ struct resp_ctx {
     struct session_recording_conf sr_conf;
 
     uint32_t cache_req_num;
+    uint32_t client_id_num;
 
     void *pvt_ctx;
 
@@ -170,12 +164,14 @@ struct cli_ctx {
     int priv;
 
     struct cli_creds *creds;
+    char *cmd_line;
 
     void *protocol_ctx;
     void *state_ctx;
 
     struct tevent_timer *idle;
     time_t last_request_time;
+    uint32_t client_id_num;
 };
 
 struct sss_cmd_table {
@@ -271,6 +267,7 @@ enum sss_dp_acct_type {
     SSS_DP_USER = 1,
     SSS_DP_GROUP,
     SSS_DP_INITGROUPS,
+    SSS_DP_SUBID_RANGES,
     SSS_DP_NETGR,
     SSS_DP_SERVICES,
     SSS_DP_SECID,
