@@ -63,7 +63,7 @@ nss_clear_memcache(TALLOC_CTX *mem_ctx,
         if (ret == ENOENT) {
             DEBUG(SSSDBG_TRACE_FUNC,
                   "CLEAR_MC_FLAG not found. Nothing to do.\n");
-            return ret;
+            return EOK; /* Most probably log rotation SIGHUP to monitor */
         } else {
             DEBUG(SSSDBG_CRIT_FAILURE,
                   "Failed to check existence of "CLEAR_MC_FLAG": %s.\n",
@@ -72,7 +72,13 @@ nss_clear_memcache(TALLOC_CTX *mem_ctx,
         }
     }
 
-    /* CLEAR_MC_FLAG found. Clearing memory caches. */
+    /*
+     * CLEAR_MC_FLAG flag file found.
+     * This file existance indicates that SIGHUP was called by sss_cache
+     * as trigger for the memory cache cleanup.
+     * sss_cache is waiting for CLEAR_MC_FLAG file deletion
+     * as confirmation that memory cache cleaning has finished.
+     */
 
     ret = confdb_get_int(nctx->rctx->cdb,
                          CONFDB_NSS_CONF_ENTRY,
@@ -80,7 +86,8 @@ nss_clear_memcache(TALLOC_CTX *mem_ctx,
                          300, &memcache_timeout);
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
-              "Unable to get memory cache entry timeout.\n");
+              "Unable to get memory cache entry timeout [%s].\n",
+              CONFDB_MEMCACHE_TIMEOUT);
         goto done;
     }
 
@@ -124,6 +131,33 @@ done:
     return ret;
 }
 
+static errno_t
+nss_clear_negcache(TALLOC_CTX *mem_ctx,
+                   struct sbus_request *sbus_req,
+                   struct nss_ctx *nctx)
+{
+    errno_t ret;
+
+    DEBUG(SSSDBG_TRACE_FUNC, "Clearing negative cache non-permament entries\n");
+
+    ret = sss_ncache_reset_users(nctx->rctx->ncache);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Negative cache clearing users failed\n");
+        goto done;
+    }
+
+    ret = sss_ncache_reset_groups(nctx->rctx->ncache);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Negative cache clearing groups failed\n");
+        goto done;
+    }
+
+done:
+    return ret;
+}
+
 static errno_t
 nss_clear_netgroup_hash_table(TALLOC_CTX *mem_ctx,
                               struct sbus_request *sbus_req,
@@ -221,12 +255,14 @@ static int setup_memcaches(struct nss_ctx *nctx)
     static const size_t SSS_MC_CACHE_PASSWD_SIZE    =  8;
     static const size_t SSS_MC_CACHE_GROUP_SIZE     =  6;
     static const size_t SSS_MC_CACHE_INITGROUP_SIZE = 10;
+    static const size_t SSS_MC_CACHE_SID_SIZE       =  6;
 
     int ret;
     int memcache_timeout;
     int mc_size_passwd;
     int mc_size_group;
     int mc_size_initgroups;
+    int mc_size_sid;
 
     /* Remove the CLEAR_MC_FLAG file if exists. */
     ret = unlink(SSS_NSS_MCACHE_DIR"/"CLEAR_MC_FLAG);
@@ -248,7 +284,7 @@ static int setup_memcaches(struct nss_ctx *nctx)
         return ret;
     }
 
-    /* Get all memcache sizes from confdb (pwd, grp, initgr) */
+    /* Get all memcache sizes from confdb (pwd, grp, initgr, sid) */
 
     ret = confdb_get_int(nctx->rctx->cdb,
                          CONFDB_NSS_CONF_ENTRY,
@@ -286,6 +322,18 @@ static int setup_memcaches(struct nss_ctx *nctx)
         return ret;
     }
 
+    ret = confdb_get_int(nctx->rctx->cdb,
+                         CONFDB_NSS_CONF_ENTRY,
+                         CONFDB_NSS_MEMCACHE_SIZE_SID,
+                         SSS_MC_CACHE_SID_SIZE,
+                         &mc_size_sid);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Failed to get '"CONFDB_NSS_MEMCACHE_SIZE_SID
+              "' option from confdb.\n");
+        return ret;
+    }
+
     /* Initialize the fast in-memory caches if they were not disabled */
 
     ret = sss_mmap_cache_init(nctx, "passwd",
@@ -324,6 +372,18 @@ static int setup_memcaches(struct nss_ctx *nctx)
               sss_strerror(ret));
     }
 
+    ret = sss_mmap_cache_init(nctx, "sid",
+                              nctx->mc_uid, nctx->mc_gid,
+                              SSS_MC_SID,
+                              mc_size_sid * SSS_MC_CACHE_SLOTS_PER_MB,
+                              (time_t)memcache_timeout,
+                              &nctx->sid_mc_ctx);
+    if (ret) {
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Failed to initialize sid mmap cache: '%s'\n",
+              sss_strerror(ret));
+    }
+
     return EOK;
 }
 
@@ -339,7 +399,8 @@ nss_register_service_iface(struct nss_ctx *nss_ctx,
             SBUS_SYNC(METHOD, sssd_service, resInit, monitor_common_res_init, NULL),
             SBUS_SYNC(METHOD, sssd_service, rotateLogs, responder_logrotate, rctx),
             SBUS_SYNC(METHOD, sssd_service, clearEnumCache, nss_clear_netgroup_hash_table, nss_ctx),
-            SBUS_SYNC(METHOD, sssd_service, clearMemcache, nss_clear_memcache, nss_ctx)
+            SBUS_SYNC(METHOD, sssd_service, clearMemcache, nss_clear_memcache, nss_ctx),
+            SBUS_SYNC(METHOD, sssd_service, clearNegcache, nss_clear_negcache, nss_ctx)
         ),
         SBUS_SIGNALS(SBUS_NO_SIGNALS),
         SBUS_PROPERTIES(SBUS_NO_PROPERTIES)
@@ -625,14 +686,11 @@ int main(int argc, const char *argv[])
 
     poptFreeContext(pc);
 
-    DEBUG_INIT(debug_level);
-
     /* set up things like debug, signals, daemonization, etc. */
     debug_log_file = "sssd_nss";
+    DEBUG_INIT(debug_level, opt_logger);
 
-    sss_set_logger(opt_logger);
-
-    ret = server_setup("nss", 0, uid, gid, CONFDB_NSS_CONF_ENTRY,
+    ret = server_setup("nss", true, 0, uid, gid, CONFDB_NSS_CONF_ENTRY,
                        &main_ctx);
     if (ret != EOK) return 2;
 
