@@ -5,8 +5,7 @@
 :subsystemteam: sst_idm_sssd
 :upstream: yes
 """
-import configparser as ConfigParser
-import pytest
+
 from utils_config import set_param, remove_section
 
 
@@ -55,7 +54,7 @@ class TestSSSDConfig(object):
         set_param(multihost, 'pam', 'debug_level', '1')
         set_param(multihost, 'nss', 'debug_level', '1')
         multihost.master[0].run_command(
-                '/usr/sbin/sssd --genconf-section=pam')
+            '/usr/sbin/sssd --genconf-section=pam')
 
         # We only told genconf to touch the pam section..
         self._assert_config_value(multihost, 'pam', 'debug_level', '1')
@@ -79,7 +78,7 @@ class TestSSSDConfig(object):
         set_param(multihost, 'foo', 'bar', 'baz')
 
         multihost.master[0].run_command(
-                '/usr/sbin/sssd --genconf-section=foo')
+            '/usr/sbin/sssd --genconf-section=foo')
 
         ldb_cmd = 'ldbsearch -H /var/lib/sss/db/config.ldb -b cn=foo,cn=config'
         cmd = multihost.master[0].run_command(ldb_cmd)
@@ -87,7 +86,7 @@ class TestSSSDConfig(object):
 
         remove_section(multihost, 'foo')
         multihost.master[0].run_command(
-                '/usr/sbin/sssd --genconf-section=foo')
+            '/usr/sbin/sssd --genconf-section=foo')
 
         ldb_cmd = 'ldbsearch -H /var/lib/sss/db/config.ldb -b cn=foo,cn=config'
         cmd = multihost.master[0].run_command(ldb_cmd)
@@ -106,4 +105,4 @@ class TestSSSDConfig(object):
         """
         multihost.master[0].service_sssd('restart')
         multihost.master[0].run_command(
-                '/usr/sbin/sssd --genconf-section=xyz')
+            '/usr/sbin/sssd --genconf-section=xyz')
